Package 'iSEEid'

Title: iSEE extension to assist in identifying sets of samples/cells
Description: This package provides a dedicated panel to assist the sample identification within a single iSEE web-application. The main functionality of this package can be adopted to efficiently select samples (e.g. cells) that need to be identified and annotated in the analysis workflow. With iSEEid, the iSEE framework fully qualifies to be an ideal companion for assigning appropriate labels to large omics datasets.
Authors: Federico Marini [aut, cre] (ORCID: <https://orcid.org/0000-0003-3252-7758>), Kevin Rue-Albrecht [aut] (ORCID: <https://orcid.org/0000-0003-3899-3872>), Charlotte Soneson [aut] (ORCID: <https://orcid.org/0000-0003-3833-2169>)
Maintainer: Federico Marini <[email protected]>
License: MIT + file LICENSE
Version: 0.99.0
Built: 2026-05-19 17:03:45 UTC
Source: https://github.com/BiocStaging/iSEEid

Help Index


The SampleIdentificationCenter class

Description

The SampleIdentificationCenter is a iSEE::Panel subclass that is dedicated to generating ready-to-use R code for assigning a sample label to samples received by a selection from another panel.

Value

A panel designed to work within the iSEE framework

Slot overview

The following slots control the behavior of the panel:

  • EditorUsageMode, a logical scalar determining whether to show the full R command for making the sample label assignments (if FALSE, displays the sample id list as plain text).

  • AnnotationRationale, a string specifying the rationale for the sample label assignment.

  • CellTypeLabel, a string providing the label to assign to the selected samples.

  • ColDataColumn, a string indicating the name of the colData column to store the assigned labels.

In addition, this class inherits all slots from its parent iSEE::Panel class.

Constructor

SampleIdentificationCenter(...) creates an instance of a SampleIdentificationCenter class, where any slot and its value can be passed to ... as a named argument.

Supported methods

In the following code snippets, x is an instance of a SampleIdentificationCenter class.

Author(s)

Federico Marini

See Also

iSEE::Panel, for the base class.

Examples

library(iSEE)
library(scRNAseq)

# Example data ----
sce <- ReprocessedAllenData(assays = "tophat_counts")
class(sce)

library(scater)
library(scrapper)
sce <- normalizeRnaCounts.se(sce, assay.type = "tophat_counts", size.factors = NULL)

sce <- runPCA(sce, ncomponents=4)
sce <- runTSNE(sce)
rowData(sce)$ave_count <- rowMeans(assay(sce, "tophat_counts"))
rowData(sce)$n_cells <- rowSums(assay(sce, "tophat_counts") > 0)

# launch the app itself ----

if (interactive()) {
  iSEE(sce, initial = list(
       ReducedDimensionPlot(),
       SampleIdentificationCenter(
         ColumnSelectionSource = "ReducedDimensionPlot1"
      )
    )
  )
}